Module keyboard

Module keyboard 

HID keyboards

Structs

BootKeyboard
Interface implementing the HID boot keyboard specification
BootKeyboardConfig
BootKeyboardReport
Report implementing the HID boot keyboard specification
KeyboardLedsReport
Report indicating the currently lit keyboard LEDs
NKROBootKeyboard
Interface implementing a NKRO keyboard compatible with the HID boot keyboard specification
NKROBootKeyboardConfig
NKROBootKeyboardReport
Report implementing an NKRO keyboard as a bitmap appended to the boot keyboard report format

Constants

BOOT_KEYBOARD_REPORT_DESCRIPTOR
HID Keyboard report descriptor conforming to the Boot specification
NKRO_BOOT_KEYBOARD_REPORT_DESCRIPTOR
HID Keyboard report descriptor implementing an NKRO keyboard as a bitmap appended to the boot keyboard report format.
NKRO_COMPACT_KEYBOARD_REPORT_DESCRIPTOR
HID Keyboard report descriptor implementing an NKRO keyboard as a bitmap.