pub struct MultiaxisReport {
pub x: i8,
pub y: i8,
pub z: i8,
pub rx: i8,
pub ry: i8,
pub rz: i8,
pub buttons: u8,
}Fields
x: i8y: i8z: i8rx: i8ry: i8rz: i8Trait Implementations
Sourceimpl Clone for MultiaxisReport
impl Clone for MultiaxisReport
Sourcefn clone(&self) -> MultiaxisReport
fn clone(&self) -> MultiaxisReport
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MultiaxisReport
impl Debug for MultiaxisReport
Sourceimpl Default for MultiaxisReport
impl Default for MultiaxisReport
Sourcefn default() -> MultiaxisReport
fn default() -> MultiaxisReport
Returns the “default value” for a type. Read more
Sourceimpl PackedStruct for MultiaxisReport
Structure that can be packed an unpacked into 7 bytes.
impl PackedStruct for MultiaxisReport
Structure that can be packed an unpacked into 7 bytes.
| Bit, MSB0 | Name | Type |
| 0:7 | x | i8 |
| 8:15 | y | i8 |
| 16:23 | z | i8 |
| 24:31 | rx | i8 |
| 32:39 | ry | i8 |
| 40:47 | rz | i8 |
| 48:55 | buttons | u8 |
Sourcetype ByteArray = [u8; 7]
type ByteArray = [u8; 7]
The appropriately sized byte array into which this structure will be packed, for example [u8; 2].
Sourcefn pack(&self) -> PackingResult<Self::ByteArray>
fn pack(&self) -> PackingResult<Self::ByteArray>
Packs the structure into a byte array.
Sourcefn unpack(src: &Self::ByteArray) -> Result<MultiaxisReport, PackingError>
fn unpack(src: &Self::ByteArray) -> Result<MultiaxisReport, PackingError>
Unpacks the structure from a byte array.
Sourceimpl PackedStructInfo for MultiaxisReport
impl PackedStructInfo for MultiaxisReport
Sourcefn packed_bits() -> usize
fn packed_bits() -> usize
Number of bits that this structure occupies when being packed.
Sourceimpl PartialEq for MultiaxisReport
impl PartialEq for MultiaxisReport
impl Copy for MultiaxisReport
impl Eq for MultiaxisReport
impl StructuralPartialEq for MultiaxisReport